@@ -68,7 +68,7 @@ class SecurityVarsDebugPanel(DebugPanel):
     def content(self):
         vars = {}
         request = self.request
-        context = getattr(self.request, 'context')
+        context = getattr(self.request, 'context', None)
         context_acl = getattr(context, '__acl__', [])
         userids = {
             'Unauthenticated': security.unauthenticated_userid(request),
